@@ -1,18 +1,18 @@
 ;(function(){
   var map = {
-  "commitId": "bfcde5a01074b9698bdc62b86b1c8df9ca2dabee",
+  "commitId": "9870ac8b926c529eb127c233f35781cacfa03f04",
   "branchName": "release-client-6.2.x",
-  "buildTime": "2024-11-18 06:03:11 GMT",
-  "buildVersion": "1.0.1326",
+  "buildTime": "2024-11-14 11:41:32 GMT",
+  "buildVersion": "1.0.1871",
   "css": [
-    "@zoom/client-scheduler/static/css/chunk-vendors.b08a77b8.css",
-    "@zoom/client-scheduler/static/css/index.60f74ba0.css"
+    "@zoom/client-calendar-desktop/static/css/chunk-vendors.d9550452.css",
+    "@zoom/client-calendar-desktop/static/css/app.f179756b.css"
   ],
   "js": [
-    "@zoom/client-scheduler/chunk-vendors.e689e0ca0cca45d0985b.js",
-    "@zoom/client-scheduler/index.e689e0ca0cca45d0985b.js"
+    "@zoom/client-calendar-desktop/static/js/chunk-vendors.f0d56f7f.js",
+    "@zoom/client-calendar-desktop/static/js/app.8263d224.js"
   ],
-  "key": "clientSchedulerResource"
+  "key": "@zoom/client-calendar-desktop"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
